@@ -1,4 +1,5 @@
 {-# LANGUAGE DeriveAnyClass #-}
+{-# LANGUAGE DerivingVia #-}
 {-# LANGUAGE DerivingStrategies #-}
 {-# LANGUAGE MultiParamTypeClasses #-}
 {-# LANGUAGE ScopedTypeVariables #-}
@@ -7,6 +8,11 @@ module T11768 where
 
 class C a b
 
+class D a
+
+newtype DWrapper a = DWrap a
+instance D (DWrapper a)
+
 data Foo = Foo
   deriving Eq -- ^ Documenting a single type
 
@@ -15,6 +21,7 @@ data Bar = Bar
            , Ord
            )
   deriving anyclass ( forall a. C a {- ^ Documenting forall type -} )
+  deriving D {- ^ Documenting deriving via -} via DWrapper Bar
 
 -- | Documenting a standalone deriving instance
 deriving instance Read Bar
