@@ -1,3 +1,3 @@
 {-# LANGUAGE NoFieldSelectors #-}
 module NFSExport (T(foo), foo) where -- only T(foo) is supported
-data T = MkT { foo :: Bool }
+data T = MkT { foo :: T }
