@@ -1,4 +1,4 @@
 module Package05 where
-import GHC.Hs.Types
+import GHC.Hs.Type
 import GHC.Hs.MyTypes
 import GHC.Hs.Utils
