@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE DataKinds, GADTs, PolyKinds, RankNTypes, TypeOperators, TypeFamilies
              , TypeApplications #-}
 
@@ -7,6 +6,7 @@ import Data.Kind
 
 data Peano = Zero | Succ Peano
 
+type Length :: [k] -> Peano
 type family Length (as :: [k]) :: Peano where
   Length (a : as) = Succ (Length as)
   Length '[]      = Zero
@@ -14,6 +14,7 @@ type family Length (as :: [k]) :: Peano where
 -- vis kind app
 data T f (a :: k) = MkT (f a)
 
+type F1 :: k -> (k -> Type) -> Type
 type family F1 (a :: k) (f :: k -> Type) :: Type where
   F1 @Peano a f = T @Peano f a
 
