@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# Language KindSignatures, TypeOperators, PolyKinds, TypeOperators,
              ConstraintKinds, TypeFamilies, DataKinds, GADTs,
              AllowAmbiguousTypes, InstanceSigs #-}
@@ -13,9 +12,11 @@ type a ~> b = TyFun a b -> Type
 
 type Cat ob = ob -> ob -> Type
 
-type SameKind (a :: k) (b :: k) = (() :: Constraint)
+type SameKind :: k -> k -> Constraint
+type SameKind a b = ()
 
-type family Apply (f :: a ~> b) (x :: a) :: b where
+type Apply :: (a ~> b) -> (a -> b)
+type family Apply f x where
   Apply IddSym0 x = Idd x
 
 class Varpi (f :: i ~> j) where
