@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE ConstraintKinds #-}
 {-# LANGUAGE DataKinds #-}
 {-# LANGUAGE PolyKinds #-}
@@ -9,5 +8,9 @@ module T16245 where
 import Data.Kind
 
 type Const a b = a
-type SameKind (a :: k) (b :: k) = (() :: Constraint)
-class (forall (b :: k). SameKind a b) => C (k :: Const Type a)
+
+type SameKind :: k -> k -> Constraint
+type SameKind a b = ()
+
+type C :: forall a. Const Type a -> Constraint
+class (forall (b :: k). SameKind a b) => C @a k
