@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE DataKinds #-}
 {-# LANGUAGE PolyKinds #-}
 {-# LANGUAGE KindSignatures #-}
@@ -43,5 +42,6 @@ data instance In (F f) r x where
   D:R:InioFrx0 ::    R:InioFrx o i f ~ In i o ('F i o f)
 -}
 -- Requires polymorphic recursion
-data In' (f :: Code i o) :: (i -> Type) -> o -> Type where
+type In' :: Code i o -> (i -> Type) -> o -> Type
+data In' f r t where
   MkIn' :: In' g (Sum1 r (In' (F g) r)) t -> In' (F g) r t
