@@ -47,7 +47,7 @@ import Data.Functor
 import Data.IORef
 import Data.Int
 import Data.Ix
-import Data.List ()  -- -Wno-compat-unqualified-imports
+import Data.List
 import Data.Maybe
 import Data.Monoid
 import Data.Ord
