@@ -8,7 +8,7 @@ import System.IO
 -- attempting to mix GADT and normal constructors
 $( return
    [ DataD [] (mkName "T")
-           [ PlainTV (mkName "a") () ]
+           [ PlainTV (mkName "a") BndrReq ]
            (Just StarT)
            [ NormalC
                (mkName "MkT")
@@ -23,7 +23,7 @@ $( return
                      [AppT (AppT EqualityT (VarT $ mkName "a"  ) )
                                            (ConT $ mkName "Int") ] $
              RecGadtC
-                 [ (mkName "MkC")]
+                 [mkName "MkC"]
                  [ ( mkName "foo"
                    , Bang NoSourceUnpackedness NoSourceStrictness
                    , VarT (mkName "a")
